==> inuits_policy_based_auth-6.3.0.tar.gz: inuits_policy_based_auth-6.3.0/src/inuits_policy_based_auth/contexts/user_context.py <==
from collections.abc import MutableMapping
from inuits_policy_based_auth.helpers.access_restrictions import AccessRestrictions
from inuits_policy_based_auth.helpers.immutable_dict import ImmutableDict


class UserContext:
    """
    A class containing data about the authenticated user.

    Properties
    ----------
    auth_objects : ImmutableDict
        An immutable dict containing objects used to authenticate a user,
        for example a token.
    email : str
        The email of the authenticated user.
    roles : list[str]
        The roles of the authenticated user.
    scopes : list[str]
        The scopes of the authenticated user.
    tenant_names : list[str]
        Names of the tenants the authenticated user is part of.
    tenant_objects : list[str]
        Object representations of the tenants the authenticated user is part of.
    bag : dict
        Dict that can contain any kind of information. It enables the possibility
        to share values dynamically between policies themselves or between
        policies and the api.
    access_restrictions : AccessRestrictions
        A class containing properties used to restrict access.

    Methods
    -------
    flatten_auth_object(data, parent_key)
        Flattens the auth object to be a dict of one level deep.
    """

    def __init__(self):
        self._auth_objects = ImmutableDict({})
        self._email = ""
        self._roles = []
        self._scopes = []
        self._tenant_names = []
        self._tenant_objects = []
        self._bag = {}
        self._access_restrictions = AccessRestrictions()

    @property
    def auth_objects(self):
        """
        An immutable dict containing objects used to authenticate a user,
        for example a token.
        """

        return self._auth_objects

    @property
    def email(self):
        """The email of the authenticated user."""

        return self._email

    @email.setter
    def email(self, email: str):
        self._email = email

    @property
    def roles(self):
        """The roles of the authenticated user."""

        return self._roles

    @roles.setter
    def roles(self, roles: list[str]):
        self._roles = roles

    @property
    def scopes(self):
        """The scopes of the authenticated user."""

        return self._scopes

    @scopes.setter
    def scopes(self, scopes: list[str]):
        self._scopes = scopes

    @property
    def tenant_names(self):
        """Names of the tenants the authenticated user is part of."""

        return self._tenant_names

    @tenant_names.setter
    def tenant_names(self, names: list[str]):
        self._tenant_names = names

    @property
    def tenant_objects(self):
        """
        Object representations of the tenants the authenticated user is part of.
        """

        return self._tenant_objects

    @tenant_objects.setter
    def tenant_objects(self, objects: list):
        self._tenant_objects = objects

    @property
    def bag(self):
        """
        Dict that can contain any kind of information. It enables the possibility
        to share values dynamically between policies themselves or between
        policies and the api.
        """

        return self._bag

    @bag.setter
    def bag(self, bag: dict):
        self._bag = bag

    @property
    def access_restrictions(self):
        """A class containing properties used to restrict access."""

        return self._access_restrictions

    def __flatten_auth_object_generator(self, data: MutableMapping, parent_key):
        for key, value in data.items():
            flattened_key = parent_key + "." + key if parent_key else key
            if isinstance(value, MutableMapping):
                yield from self.flatten_auth_object(value, flattened_key).items()
            else:
                yield flattened_key, value

    def flatten_auth_object(self, data: MutableMapping, parent_key=""):
        """Flattens the auth object to be a dict of one level deep.

        Parameters
        ----------
        data : MutableMapping
            An object used to authenticate a user with, for example a token.
        parent_key : str, optional
            A key that will be the root key for the flattened dict.

        Returns
        -------
        dict
            A flattened dictionary representation of the auth object.
        """

        return dict(self.__flatten_auth_object_generator(data, parent_key))

==> inuits_policy_based_auth-9.3.1.tar.gz: inuits_policy_based_auth-9.3.1/src/inuits_policy_based_auth/contexts/user_context.py <==
from collections.abc import MutableMapping
from inuits_policy_based_auth.helpers.access_restrictions import AccessRestrictions
from inuits_policy_based_auth.helpers.immutable_dict import ImmutableDict
from inuits_policy_based_auth.helpers.tenant import Tenant


class UserContext:
    """
    A class containing data about the authenticated user.

    Properties
    ----------
    auth_objects : ImmutableDict
        An immutable dict containing objects used to authenticate a user,
        for example a token.
    id : str
        The id of the authenticated user.
    email : str
        The email of the authenticated user.
    x_tenant : Tenant
        The user tenant that is requested from the X-Tenant-Id http header.
    tenants : list[Tenant]
        All tenants that are related to the user.
    bag : dict
        Dict that can contain any kind of information. It enables the possibility
        to share values dynamically between policies themselves or between
        policies and the api.
    access_restrictions : AccessRestrictions
        A class containing properties used to restrict access.

    Methods
    -------
    flatten_auth_object(data, parent_key)
        Flattens the auth object to be a dict of one level deep.
    """

    def __init__(self):
        self._auth_objects = ImmutableDict({})
        self._id = ""
        self._email = ""
        self._x_tenant = Tenant()
        self._tenants: list[Tenant] = []
        self._bag = {}
        self._access_restrictions = AccessRestrictions()

    @property
    def auth_objects(self):
        """
        An immutable dict containing objects used to authenticate a user,
        for example a token.
        """

        return self._auth_objects

    @property
    def id(self):
        """The id of the authenticated user."""

        return self._id

    @id.setter
    def id(self, id: str):
        self._id = id

    @property
    def email(self):
        """The email of the authenticated user."""

        return self._email

    @email.setter
    def email(self, email: str):
        self._email = email

    @property
    def x_tenant(self):
        """The user tenant that is requested from the X-Tenant-Id http header."""

        return self._x_tenant

    @x_tenant.setter
    def x_tenant(self, x_tenant: Tenant):
        self._x_tenant = x_tenant

    @property
    def tenants(self):
        """All tenants that are related to the user."""

        return self._tenants

    @tenants.setter
    def tenants(self, tenants: list[Tenant]):
        self._tenants = tenants

    @property
    def bag(self):
        """
        Dict that can contain any kind of information. It enables the possibility
        to share values dynamically between policies themselves or between
        policies and the api.
        """

        return self._bag

    @bag.setter
    def bag(self, bag: dict):
        self._bag = bag

    @property
    def access_restrictions(self):
        """A class containing properties used to restrict access."""

        return self._access_restrictions

    def __flatten_auth_object_generator(self, data: MutableMapping, parent_key):
        for key, value in data.items():
            flattened_key = parent_key + "." + key if parent_key else key
            if isinstance(value, MutableMapping):
                yield from self.flatten_auth_object(value, flattened_key).items()
            else:
                yield flattened_key, value

    def flatten_auth_object(self, data: MutableMapping, parent_key=""):
        """Flattens the auth object to be a dict of one level deep.

        Parameters
        ----------
        data : MutableMapping
            An object used to authenticate a user with, for example a token.
        parent_key : str, optional
            A key that will be the root key for the flattened dict.

        Returns
        -------
        dict
            A flattened dictionary representation of the auth object.
        """

        return dict(self.__flatten_auth_object_generator(data, parent_key))
